@@ -54,11 +54,11 @@
 #include <apt-pkg/strutl.h>
 
 #include <boost/format.hpp>
-#include <boost/scoped_ptr.hpp>
 
 #include <sigc++/bind.h>
 
 #include <algorithm>
+#include <memory>
 
 using namespace std;
 namespace cw = cwidget;
@@ -79,7 +79,6 @@ using aptitude::util::progress_type_pulse;
 using aptitude::util::throttle;
 using aptitude::views::progress;
 using boost::format;
-using boost::shared_ptr;
 using cwidget::util::ref_ptr;
 using cwidget::util::transcode;
 using namespace aptitude::matching;
@@ -94,16 +93,16 @@ namespace
                          const unsigned int screen_width,
                          bool disable_columns,
                          bool debug,
-                         const shared_ptr<terminal_locale> &term_locale,
-                         const shared_ptr<terminal_metrics> &term_metrics,
-                         const shared_ptr<terminal_output> &term_output)
+                         const std::shared_ptr<terminal_locale> &term_locale,
+                         const std::shared_ptr<terminal_metrics> &term_metrics,
+                         const std::shared_ptr<terminal_output> &term_output)
   {
     typedef std::vector<std::pair<pkgCache::PkgIterator, ref_ptr<structural_match> > >
       results_list;
 
-    const shared_ptr<progress> search_progress_display =
+    const std::shared_ptr<progress> search_progress_display =
       create_progress_display(term_locale, term_metrics, term_output);
-    const shared_ptr<throttle> search_progress_throttle =
+    const std::shared_ptr<throttle> search_progress_throttle =
       create_throttle();
 
     results_list output;
@@ -111,7 +110,7 @@ namespace
     for(std::vector<ref_ptr<pattern> >::const_iterator pIt = patterns.begin();
         pIt != patterns.end(); ++pIt)
       {
-        const shared_ptr<progress> search_progress =
+        const std::shared_ptr<progress> search_progress =
           create_search_progress(serialize_pattern(*pIt),
                                  search_progress_display,
                                  search_progress_throttle);
@@ -167,7 +166,7 @@ int cmdline_search(int argc, char *argv[], const char *status_fname,
 		   string display_format, string width, string sort,
 		   bool disable_columns, bool debug)
 {
-  shared_ptr<terminal_io> term = create_terminal();
+  std::shared_ptr<terminal_io> term = create_terminal();
 
   int real_width=-1;
 
@@ -191,6 +190,12 @@ int cmdline_search(int argc, char *argv[], const char *status_fname,
       real_width=tmp;
     }
 
+  if(!disable_columns && !pkg_item::pkg_columnizer::check_valid_display_format(display_format, PACKAGE "::CmdLine::Package-Display-Format" " (or -F)"))
+    {
+      _error->DumpErrors();
+      return -1;
+    }
+
   wstring wdisplay_format;
 
   if(!cw::util::transcode(display_format.c_str(), wdisplay_format))
@@ -200,7 +205,7 @@ int cmdline_search(int argc, char *argv[], const char *status_fname,
       return -1;
     }
 
-  boost::scoped_ptr<column_definition_list> columns;
+  std::unique_ptr<column_definition_list> columns;
   columns.reset(parse_columns(wdisplay_format,
                               pkg_item::pkg_columnizer::parse_column_type,
                               pkg_item::pkg_columnizer::defaults));
@@ -217,7 +222,7 @@ int cmdline_search(int argc, char *argv[], const char *status_fname,
       return -1;
     }
 
-  shared_ptr<OpProgress> progress =
+  std::shared_ptr<OpProgress> progress =
     make_text_progress(true, term, term, term);
 
   apt_init(progress.get(), true, status_fname);
