@@ -66,7 +66,6 @@ using aptitude::cmdline::terminal_locale;
 using aptitude::cmdline::terminal_metrics;
 using aptitude::cmdline::terminal_output;
 using aptitude::controllers::acquire_download_progress;
-using boost::shared_ptr;
 
 namespace
 {
@@ -113,7 +112,7 @@ void ui_solution_screen()
 }
 
 void cmdline_show_stringlist(strvector &items,
-                             const shared_ptr<terminal_metrics> &term_metrics)
+                             const std::shared_ptr<terminal_metrics> &term_metrics)
 {
   const unsigned int screen_width = term_metrics->get_screen_width();
 
@@ -137,7 +136,7 @@ void cmdline_show_stringlist(strvector &items,
 }
 
 void cmdline_show_pkglist(pkgvector &items,
-                          const shared_ptr<terminal_metrics> &term_metrics)
+                          const std::shared_ptr<terminal_metrics> &term_metrics)
 {
   strvector tmp;
 
@@ -346,7 +345,7 @@ namespace
   void show_stats_change(stats initial, stats final,
 			 bool show_all,
 			 bool show_unchanged,
-                         const shared_ptr<terminal_metrics> &term_metrics)
+                         const std::shared_ptr<terminal_metrics> &term_metrics)
   {
     using cw::fragf;
     using cw::util::ssprintf;
@@ -358,8 +357,8 @@ namespace
        final.get_num_broken() != initial.get_num_broken())
       {
 	std::string change =
-	  ssprintf(ngettext("%d broken [%+d]",
-			    "%d broken [%+d]",
+	  ssprintf(ngettext("%d (%+d) broken",
+			    "%d (%+d) broken",
 			    final.get_num_broken()),
 		   final.get_num_broken(),
 		   final.get_num_broken() - initial.get_num_broken());
@@ -372,8 +371,8 @@ namespace
        final.get_num_upgradable() != initial.get_num_upgradable())
       {
 	std::string change =
-	  ssprintf(ngettext("%d update [%+d]",
-			    "%d updates [%+d]",
+	  ssprintf(ngettext("%d (%+d) upgradable",
+			    "%d (%+d) upgradable",
 			    final.get_num_upgradable()),
 		   final.get_num_upgradable(),
 		   final.get_num_upgradable() - initial.get_num_upgradable());
@@ -386,8 +385,8 @@ namespace
        final.get_num_new() != initial.get_num_new())
       {
 	std::string change =
-	  ssprintf(ngettext("%d new [%+d]",
-			    "%d new [%+d]",
+	  ssprintf(ngettext("%d (%+d) new",
+			    "%d (%+d) new",
 			    final.get_num_new()),
 		   final.get_num_new(),
 		   final.get_num_new() - initial.get_num_new());
@@ -449,13 +448,13 @@ namespace
 
 download_manager::result cmdline_do_download(download_manager *m,
 					     int verbose,
-                                             const shared_ptr<terminal_input> &term_input,
-                                             const shared_ptr<terminal_locale> &term_locale,
-                                             const shared_ptr<terminal_metrics> &term_metrics,
-                                             const shared_ptr<terminal_output> &term_output)
+                                             const std::shared_ptr<terminal_input> &term_input,
+                                             const std::shared_ptr<terminal_locale> &term_locale,
+                                             const std::shared_ptr<terminal_metrics> &term_metrics,
+                                             const std::shared_ptr<terminal_output> &term_output)
 {
   stats initial_stats(0, 0, 0, std::set<std::string>());
-  shared_ptr<OpProgress> progress = make_text_progress(false, term_locale, term_metrics, term_output);
+  std::shared_ptr<OpProgress> progress = make_text_progress(false, term_locale, term_metrics, term_output);
 
   if(aptcfg->FindI("Quiet", 0) == 0)
     {
@@ -469,13 +468,13 @@ download_manager::result cmdline_do_download(download_manager *m,
       initial_stats = compute_apt_stats();
     }
 
-  std::pair<download_signal_log *, boost::shared_ptr<acquire_download_progress> >
+  std::pair<download_signal_log *, std::shared_ptr<acquire_download_progress> >
     progress_display = create_cmdline_download_progress(term_input,
                                                         term_locale,
                                                         term_metrics,
                                                         term_output);
 
-  std::auto_ptr<download_signal_log> log(progress_display.first);
+  std::unique_ptr<download_signal_log> log(progress_display.first);
 
   // Dump errors here because prepare() might check for pending errors
   // and think something failed.
@@ -594,7 +593,7 @@ namespace aptitude
 	  for(vector<pkgIndexFile *>::const_iterator j = indexes->begin();
 	      j != indexes->end(); ++j)
 	    {
-	      std::auto_ptr<pkgSrcRecords::Parser> p((*j)->CreateSrcParser());
+	      std::unique_ptr<pkgSrcRecords::Parser> p((*j)->CreateSrcParser());
 
 	      if(_error->PendingError())
 		return source_package();
@@ -673,26 +672,33 @@ namespace aptitude
 
 	  if(!ver.end())
 	    {
+#if APT_PKG_MAJOR >= 5
+	      // with apt-1.1:
+	      //
+	      // - SourcePkg (and Version) are in the binary cache and available via
+	      //   the VerIterator; much faster than parsing the pkgRecord
+	      //
+	      // - defaults to package name, no need to check if it's empty
+	      source_package_name = ver.SourcePkgName();
+	      source_version = ver.SourceVerStr();
+
+	      rval = find_source_package(source_package_name, source_version);
+#else
 	      pkgRecords::Parser &rec =
 		apt_package_records->Lookup(ver.FileList());
 
 	      if(!rec.SourcePkg().empty())
 		source_package_name = rec.SourcePkg();
 
-	      if(version_source == cmdline_version_version)
+	      if(version_source == cmdline_version_version
+		 || version_source == cmdline_version_curr_or_cand)
 		{
 		  const std::string source_version =
 		    rec.SourceVer().empty() ? ver.VerStr() : rec.SourceVer();
 
 		  rval = find_source_package(source_package_name, source_version);
 		}
-	      else if(version_source == cmdline_version_curr_or_cand)
-		{
-		  const std::string source_version =
-		    rec.SourceVer().empty() ? ver.VerStr() : rec.SourceVer();		  
-
-		  rval = find_source_package(source_package_name, source_version);
-		}
+#endif
 	    }
 	  // Last-ditch effort: if no matching version was found but
 	  // a source package can be found, use that and try again below.
