@@ -17,11 +17,6 @@
 //   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 //   Boston, MA 02111-1307, USA.
 
-// g++ generates a spurious warning in a call to std::sort below;
-// downgrade it to a non-error.
-#pragma GCC diagnostic warning "-Wuninitialized"
-
-
 // Local includes:
 #include "cmdline_why.h"
 
@@ -50,8 +45,6 @@
 #include <apt-pkg/pkgsystem.h>
 #include <apt-pkg/version.h>
 
-#include <boost/make_shared.hpp>
-
 #include <cwidget/fragment.h>
 
 #include <algorithm>
@@ -64,8 +57,6 @@ using aptitude::cmdline::terminal_io;
 using aptitude::cmdline::terminal_metrics;
 using aptitude::why::make_cmdline_why_callbacks;
 using aptitude::why::why_callbacks;
-using boost::make_shared;
-using boost::shared_ptr;
 using cwidget::fragf;
 using cwidget::fragment;
 
@@ -146,7 +137,7 @@ namespace aptitude
       void generate_successors(std::deque<justification> &output,
 			       const search_params &params,
 			       int verbosity,
-                               const shared_ptr<why_callbacks> &callbacks) const
+                               const std::shared_ptr<why_callbacks> &callbacks) const
       {
 	the_target.generate_successors(*this, output, params, verbosity, callbacks);
       }
@@ -398,7 +389,7 @@ namespace aptitude
 				   std::deque<justification> &output,
 				   const search_params &params,
 				   int verbosity,
-                                   const shared_ptr<why_callbacks> &callbacks) const
+                                   const std::shared_ptr<why_callbacks> &callbacks) const
   {
     why_callbacks * const callbacks_bare = callbacks.get();
 
@@ -704,7 +695,7 @@ namespace aptitude
      *  \return true if a justification was found, false otherwise.
      */
     bool next(std::vector<action> &output,
-              const boost::shared_ptr<why_callbacks> &callbacks)
+              const std::shared_ptr<why_callbacks> &callbacks)
     {
       why_callbacks * const callbacks_bare = callbacks.get();
 
@@ -798,7 +789,7 @@ namespace aptitude
 			    const std::vector<cwidget::util::ref_ptr<pattern> > leaves,
 			    const search_params &params,
 			    bool find_all,
-                            const boost::shared_ptr<why_callbacks> &callbacks,
+                            const std::shared_ptr<why_callbacks> &callbacks,
 			    std::vector<std::vector<action> > &output)
     {
       justification_search search(leaves, target, params, 0);
@@ -828,7 +819,7 @@ namespace aptitude
 				 const target &goal,
 				 bool find_all,
 				 int verbosity,
-                                 const shared_ptr<why_callbacks> &callbacks,
+                                 const std::shared_ptr<why_callbacks> &callbacks,
 				 std::vector<std::vector<action> > &output)
     {
       std::vector<search_params> searches;
@@ -1054,12 +1045,12 @@ namespace aptitude
     {
       class cmdline_why_callbacks : public why_callbacks
       {
-        const shared_ptr<terminal_metrics> term_metrics;
+        const std::shared_ptr<terminal_metrics> term_metrics;
         const int verbosity;
         const unsigned int screen_width;
 
       public:
-        cmdline_why_callbacks(const shared_ptr<terminal_metrics> &_term_metrics,
+        cmdline_why_callbacks(const std::shared_ptr<terminal_metrics> &_term_metrics,
                               const int _verbosity)
           : term_metrics(_term_metrics),
             verbosity(_verbosity),
@@ -1071,7 +1062,7 @@ namespace aptitude
         {
           if(verbosity > 1)
             {
-              std::auto_ptr<cw::fragment> tmp(cw::fragf(_("    ++ Examining %F\n"), print_dep(dep)));
+              std::unique_ptr<cw::fragment> tmp(cw::fragf(_("    ++ Examining %F\n"), print_dep(dep)));
               std::cout << tmp->layout(screen_width, screen_width, cw::style());
             }
         }
@@ -1144,9 +1135,9 @@ namespace aptitude
         {
           if(verbosity > 1)
             {
-              std::auto_ptr<cw::fragment> desc(justification_description(target, actions));
+              std::unique_ptr<cw::fragment> desc(justification_description(target, actions));
 
-              std::auto_ptr<cw::fragment> f(cw::fragf("Search for %F\n",
+              std::unique_ptr<cw::fragment> f(cw::fragf("Search for %F\n",
                                                       desc.release()));
               std::cout << f->layout(screen_width,
                                      screen_width,
@@ -1156,11 +1147,11 @@ namespace aptitude
       };
     }
 
-    shared_ptr<why_callbacks>
+    std::shared_ptr<why_callbacks>
     make_cmdline_why_callbacks(const int verbosity,
-                               const shared_ptr<terminal_metrics> &term_metrics)
+                               const std::shared_ptr<terminal_metrics> &term_metrics)
     {
-      return make_shared<cmdline_why_callbacks>(term_metrics, verbosity);
+      return std::make_shared<cmdline_why_callbacks>(term_metrics, verbosity);
     }
   }
 }
@@ -1170,7 +1161,7 @@ cw::fragment *do_why(const std::vector<cwidget::util::ref_ptr<pattern> > &leaves
 		     aptitude::why::roots_string_mode display_mode,
 		 int verbosity,
 		 bool root_is_removal,
-                     const shared_ptr<why_callbacks> &callbacks,
+                     const std::shared_ptr<why_callbacks> &callbacks,
 		 bool &success)
 {
   using namespace aptitude::why;
@@ -1248,15 +1239,15 @@ int do_why(const std::vector<cwidget::util::ref_ptr<pattern> > &leaves,
 	   aptitude::why::roots_string_mode display_mode,
 	   int verbosity,
 	   bool root_is_removal,
-           const shared_ptr<terminal_metrics> &term_metrics)
+           const std::shared_ptr<terminal_metrics> &term_metrics)
 {
   bool success = false;
-  const shared_ptr<why_callbacks> callbacks =
+  const std::shared_ptr<why_callbacks> callbacks =
     make_cmdline_why_callbacks(verbosity, term_metrics);
-  std::auto_ptr<cw::fragment> f(do_why(leaves, root, display_mode,
-				       verbosity, root_is_removal,
-				       callbacks,
-                                       success));
+  std::unique_ptr<cw::fragment> f(do_why(leaves, root, display_mode,
+					 verbosity, root_is_removal,
+					 callbacks,
+					 success));
   const unsigned int screen_width = term_metrics->get_screen_width();
   // TODO: display each result as we find it.
   std::cout << f->layout(screen_width, screen_width, cw::style());
@@ -1269,7 +1260,7 @@ cw::fragment *do_why(const std::vector<cwidget::util::ref_ptr<pattern> > &leaves
 		     aptitude::why::roots_string_mode display_mode,
 		 bool find_all,
 		 bool root_is_removal,
-                     const shared_ptr<why_callbacks> &callbacks,
+                     const std::shared_ptr<why_callbacks> &callbacks,
 		 bool &success)
 {
   const int verbosity = find_all ? 1 : 0;
@@ -1317,7 +1308,7 @@ cw::fragment *do_why(const std::vector<std::string> &arguments,
 		     aptitude::why::roots_string_mode display_mode,
 		 int verbosity,
 		 bool root_is_removal,
-                     const shared_ptr<why_callbacks> &callbacks,
+                     const std::shared_ptr<why_callbacks> &callbacks,
 		 bool &success)
 {
   success = false;
@@ -1343,7 +1334,7 @@ cw::fragment *do_why(const std::vector<std::string> &leaves,
 		     aptitude::why::roots_string_mode display_mode,
 		 bool find_all,
 		 bool root_is_removal,
-                     const shared_ptr<why_callbacks> &callbacks,
+                     const std::shared_ptr<why_callbacks> &callbacks,
 		 bool &success)
 {
   return do_why(leaves, root, display_mode, find_all ? 1 : 0,
@@ -1357,7 +1348,7 @@ int cmdline_why(int argc, char *argv[],
 		aptitude::why::roots_string_mode display_mode,
 		bool is_why_not)
 {
-  const shared_ptr<terminal_io> term = create_terminal();
+  const std::shared_ptr<terminal_io> term = create_terminal();
 
   _error->DumpErrors();
 
@@ -1555,7 +1546,6 @@ namespace aptitude
 	    {
 	      std::vector<std::pair<std::string, pkgCache::Dep::DepType> >
 		packages_by_dep_strength(roots.begin(), roots.end());
-              // g++ emits a spurious error here.  Don't know why:
 	      std::sort(packages_by_dep_strength.begin(),
 			packages_by_dep_strength.end(),
 			compare_pair_by_deptype());
