@@ -30,6 +30,7 @@
 #include <signal.h>
 
 #include <map>
+#include <memory>
 
 #undef OK
 #include <gtkmm.h>
@@ -50,8 +51,6 @@
 
 #include <sigc++/signal.h>
 
-#include <boost/make_shared.hpp>
-
 #include <cwidget/generic/threads/event_queue.h>
 #include <cwidget/generic/util/ssprintf.h>
 #include <cwidget/generic/util/transcode.h>
@@ -76,6 +75,7 @@ using aptitude::Loggers;
 
 namespace gui
 {
+  // Ensure help.txt and doc/ is kept in synchronisation with the below states
   // \todo Some of these icon choices suck.
   const entity_state_info not_installed_columns("p", N_("Not installed"), Gtk::StockID());
   const entity_state_info virtual_columns("p", N_("Virtual"), Gtk::StockID());
@@ -86,7 +86,7 @@ namespace gui
   const entity_state_info triggers_awaited_columns("W", N_("Triggers awaited"), Gtk::Stock::DIALOG_WARNING);
   const entity_state_info triggers_pending_columns("T", N_("Triggers pending"), Gtk::Stock::DIALOG_WARNING);
   const entity_state_info installed_columns("i", N_("Installed"), Gtk::Stock::YES);
-  const entity_state_info error_columns("E", "Internal Error (bad state)", Gtk::Stock::DIALOG_ERROR);
+  const entity_state_info error_columns("E", "Internal error (bad state)", Gtk::Stock::DIALOG_ERROR);
 
   const entity_state_info install_columns("i", N_("Install"), Gtk::Stock::ADD);
   const entity_state_info reinstall_columns("r", N_("Reinstall"), Gtk::Stock::ADD);
@@ -213,7 +213,7 @@ namespace gui
 					&guiOpProgress::destroy));
   }
 
-  void start_download(const boost::shared_ptr<download_manager> &manager,
+  void start_download(const std::shared_ptr<download_manager> &manager,
 		      const std::string &title,
 		      Gtk::Widget *image,
 		      download_progress_mode progress_mode,
@@ -261,7 +261,7 @@ namespace gui
   // \todo make this use the threaded download system.
   void really_do_update_lists()
   {
-    boost::shared_ptr<download_update_manager> m(boost::make_shared<download_update_manager>());
+    std::shared_ptr<download_update_manager> m(std::make_shared<download_update_manager>());
 
     active_download = true;
 
@@ -954,9 +954,9 @@ namespace gui
 
       active_download = true;
 
-      boost::shared_ptr<download_install_manager> m =
-	boost::make_shared<download_install_manager>(false,
-						     sigc::ptr_fun(&gui_run_dpkg));
+      std::shared_ptr<download_install_manager> m =
+	std::make_shared<download_install_manager>(false,
+						   sigc::ptr_fun(&gui_run_dpkg));
 
       start_download(m,
 		     _("Downloading packages"),
@@ -987,7 +987,7 @@ namespace gui
 
   void do_keep_all()
   {
-    std::auto_ptr<undo_group> undo(new apt_undo_group);
+    std::unique_ptr<undo_group> undo(new apt_undo_group);
     aptitudeDepCache::action_group group(*apt_cache_file, undo.get());
 
     for(pkgCache::PkgIterator i=(*apt_cache_file)->PkgBegin();
