@@ -1,6 +1,7 @@
 // pkg_node.h	-*-c++-*-
 //
 //  Copyright 1999-2000, 2002, 2005 Daniel Burrows
+//  Copyright 2014-2015 Manuel A. Fernandez Montecelo
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -16,8 +17,6 @@
 //  along with this program; see the file COPYING.  If not, write to
 //  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 //  Boston, MA 02111-1307, USA.
-//
-//  
 
 #ifndef PKG_NODE_H
 #define PKG_NODE_H
@@ -52,14 +51,15 @@ class pkg_tree_node:virtual public cwidget::widgets::treeitem, public menu_redir
    */
   bool package_action(void (pkg_tree_node::* action)(undo_group *));
 public:
-  virtual void select(undo_group *undo)=0;
-  virtual void hold(undo_group *undo)=0;
-  virtual void keep(undo_group *undo)=0;
-  virtual void remove(undo_group *undo)=0;
-  virtual void purge(undo_group *undo)=0;
-  virtual void reinstall(undo_group *undo)=0;
+  virtual void select(undo_group *undo) = 0;
+  virtual void hold(undo_group *undo) = 0;
+  virtual void keep(undo_group *undo) = 0;
+  virtual void remove(undo_group *undo) = 0;
+  virtual void purge(undo_group *undo) = 0;
+  virtual void reinstall(undo_group *undo) = 0;
   // set_auto is idempotent!  No stupid toggling stuff.
-  virtual void set_auto(bool isauto, undo_group *undo)=0;
+  virtual void set_auto(bool value, undo_group *undo) = 0;
+  virtual void forbid_upgrade(undo_group *undo) = 0;
 
   void mark_auto(undo_group *undo) {set_auto(true, undo);}
   void unmark_auto(undo_group *undo) {set_auto(false, undo);}
